@@ -1,27 +1,8 @@
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 #   Copyright 2009 - 2013   Clark Williams <williams@redhat.com>
 #   Copyright 2009 - 2013   David Sommerseth <davids@redhat.com>
 #
-#   This program is free software; you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
-#   (at your option) any later version.
-#
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#
-#   You should have received a copy of the GNU General Public License along
-#   with this program; if not, write to the Free Software Foundation, Inc.,
-#   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
-#   For the avoidance of doubt the "preferred form" of this code is one which
-#   is in an open unpatent encumbered format. Where cryptographic key signing
-#   forms part of the process of creating an executable the information
-#   including keys needed to generate an equivalently functional executable
-#   are deemed to be part of the source code.
-#
 
 """
 Copyright (c) 2008-2016  Red Hat Inc.
@@ -38,39 +19,43 @@ import threading
 import time
 from datetime import datetime
 import sysconfig
+from traceback import format_exception
 from rteval.modules.loads import LoadModules
-from rteval.modules.measurement import MeasurementModules, MeasurementProfile
+from rteval.modules.measurement import MeasurementModules
 from rteval.rtevalReport import rtevalReport
-from rteval.rtevalXMLRPC import rtevalXMLRPC
 from rteval.Log import Log
 from rteval import rtevalConfig
-from rteval import rtevalMailer
 from rteval import version
 
 RTEVAL_VERSION = version.RTEVAL_VERSION
 
-earlystop = False
+EARLYSTOP = False
+threaderr = False
 
-stopsig_received = False
+stopsig = threading.Event()
 def sig_handler(signum, frame):
     """ Handle SIGINT (CTRL + C) or SIGTERM (Termination signal) """
     if signum in (signal.SIGINT, signal.SIGTERM):
-        global stopsig_received
-        stopsig_received = True
+        stopsig.set()
         print("*** stop signal received - stopping rteval run ***")
     else:
         raise RuntimeError(f"SIGNAL received! ({signum})")
 
+def except_hook(args):
+    global threaderr
+
+    threading.__excepthook__(args)
+    threaderr = True
+    stopsig.set()
+
 class RtEval(rtevalReport):
     def __init__(self, config, loadmods, measuremods, logger):
         self.__version = RTEVAL_VERSION
+        threading.excepthook = except_hook
 
         if not isinstance(config, rtevalConfig.rtevalConfig):
             raise TypeError("config variable is not an rtevalConfig object")
 
-        if not isinstance(loadmods, LoadModules):
-            raise TypeError("loadmods variable is not a LoadModules object")
-
         if not isinstance(measuremods, MeasurementModules):
             raise TypeError("measuremods variable is not a MeasurementModules object")
 
@@ -89,13 +74,7 @@ class RtEval(rtevalReport):
         from .sysinfo import SystemInfo
         self._sysinfo = SystemInfo(self.__rtevcfg, logger=self.__logger)
 
-        # prepare a mailer, if that's configured
-        if self.__cfg.HasSection('smtp'):
-            self.__mailer = rtevalMailer.rtevalMailer(self.__cfg.GetSection('smtp'))
-        else:
-            self.__mailer = None
-
-        if not os.path.exists(self.__rtevcfg.xslt_report):
+        if not self.__rtevcfg.xslt_report or not os.path.exists(self.__rtevcfg.xslt_report):
             raise RuntimeError(f"can't find XSL template ({self.__rtevcfg.xslt_report})!")
 
         # Add rteval directory into module search path
@@ -110,19 +89,6 @@ class RtEval(rtevalReport):
         rtevalReport.__init__(self, self.__version,
                               self.__rtevcfg.installdir, self.__rtevcfg.annotate)
 
-        # If --xmlrpc-submit is given, check that we can access the server
-        if self.__rtevcfg.xmlrpc:
-            self.__xmlrpc = rtevalXMLRPC(self.__rtevcfg.xmlrpc, self.__logger, self.__mailer)
-            if not self.__xmlrpc.Ping():
-                if not self.__rtevcfg.xmlrpc_noabort:
-                    print(f"ERROR: Could not reach XML-RPC server '{self.__rtevcfg.xmlrpc}'.  Aborting.")
-                    sys.exit(2)
-                else:
-                    print("WARNING: Could not ping the XML-RPC server.  Will continue anyway.")
-        else:
-            self.__xmlrpc = None
-
-
     @staticmethod
     def __show_remaining_time(remaining):
         secs = int(remaining)
@@ -150,9 +116,8 @@ class RtEval(rtevalReport):
             if not onlyload or self.__rtevcfg.logging:
                 self.__reportdir = self._make_report_dir(self.__rtevcfg.workdir, "summary.xml")
         except Exception as err:
-            raise RuntimeError(f"Cannot create report directory (NFS with rootsquash on?) [{err}]]")
+            raise RuntimeError(f"Cannot create report directory (NFS with rootsquash on?) [{err}]]") from err
 
-        self.__logger.log(Log.INFO, "Preparing load modules")
         params = {'workdir':self.__rtevcfg.workdir,
                   'reportdir':self.__reportdir and self.__reportdir or "",
                   'builddir':builddir,
@@ -164,59 +129,59 @@ class RtEval(rtevalReport):
                   'memsize':self._sysinfo.mem_get_size(),
                   'numanodes':self._sysinfo.mem_get_numa_nodes(),
                   'duration': float(self.__rtevcfg.duration),
+                  'usingCpupower': self.__rtevcfg.usingCpupower
                   }
-        self._loadmods.Setup(params)
+
+        if self._loadmods:
+            self.__logger.log(Log.INFO, "Preparing load modules")
+            self._loadmods.Setup(params)
 
         self.__logger.log(Log.INFO, "Preparing measurement modules")
         self._measuremods.Setup(params)
 
 
-    def __RunMeasurementProfile(self, measure_profile):
-        global earlystop
-        if not isinstance(measure_profile, MeasurementProfile):
-            raise Exception("measure_profile is not an MeasurementProfile object")
+    def __RunMeasurement(self):
+        global EARLYSTOP
 
         measure_start = None
-        (with_loads, run_parallel) = measure_profile.GetProfile()
-        self.__logger.log(Log.INFO, f"Using measurement profile [loads: {with_loads}  parallel: {run_parallel}]")
         try:
             nthreads = 0
 
             # start the loads
-            if with_loads:
+            if self._loadmods:
                 self._loadmods.Start()
 
             print(f"rteval run on {os.uname()[2]} started at {time.asctime()}")
             onlinecpus = self._sysinfo.cpu_getCores(True)
-            cpulist = self._loadmods._cfg.GetSection("loads").cpulist
-            if cpulist:
-                print(f"started {self._loadmods.ModulesLoaded()} loads on cores {cpulist}", end=' ')
-            else:
-                print(f"started {self._loadmods.ModulesLoaded()} loads on {onlinecpus} cores", end=' ')
-            if self._sysinfo.mem_get_numa_nodes() > 1:
-                print(f" with {self._sysinfo.mem_get_numa_nodes()} numa nodes")
-            else:
-                print("")
-            cpulist = self._measuremods._MeasurementModules__cfg.GetSection("measurement").cpulist
+            if self._loadmods:
+                cpulist = self._loadmods._cfg.GetSection("loads").cpulist
+                if cpulist:
+                    print(f"started {self._loadmods.ModulesLoaded()} loads on cores {cpulist}",
+                          end=' ')
+                else:
+                    print(f"started {self._loadmods.ModulesLoaded()} loads on {onlinecpus} cores",
+                          end=' ')
+                if self._sysinfo.mem_get_numa_nodes() > 1:
+                    print(f" with {self._sysinfo.mem_get_numa_nodes()} numa nodes")
+                else:
+                    print("")
+            cpulist = self._measuremods._cfg.GetSection("measurement").cpulist
             if cpulist:
                 print(f"started measurement threads on cores {cpulist}")
             else:
                 print(f"started measurement threads on {onlinecpus} cores")
             print(f"Run duration: {str(self.__rtevcfg.duration)} seconds")
 
-            # start the cyclictest thread
-            measure_profile.Start()
+            self._measuremods.Start()
 
             # Unleash the loads and measurement threads
             report_interval = int(self.__rtevcfg.report_interval)
-            if with_loads:
+            if self._loadmods:
                 self._loadmods.Unleash()
                 nthreads = threading.active_count()
             else:
                 nthreads = None
-            self.__logger.log(Log.INFO, "Waiting 30 seconds to let load modules settle down")
-            time.sleep(30)
-            measure_profile.Unleash()
+            self._measuremods.Unleash()
             measure_start = datetime.now()
 
             # wait for time to expire or thread to die
@@ -227,19 +192,19 @@ class RtEval(rtevalReport):
             currtime = time.time()
             rpttime = currtime + report_interval
             load_avg_checked = 5
-            while (currtime <= stoptime) and not stopsig_received:
-                time.sleep(60.0)
-                if not measure_profile.isAlive():
+            while (currtime <= stoptime) and not stopsig.is_set():
+                stopsig.wait(min(stoptime - currtime, 60.0))
+                if not self._measuremods.isAlive():
                     stoptime = currtime
-                    earlystop = True
+                    EARLYSTOP = True
                     self.__logger.log(Log.WARN,
                                       "Measurement threads did not use the full time slot. Doing a controlled stop.")
 
-                if with_loads:
+                if nthreads:
                     if threading.active_count() < nthreads:
                         raise RuntimeError("load thread died!")
 
-                if not load_avg_checked:
+                if self._loadmods and not load_avg_checked:
                     self._loadmods.SaveLoadAvg()
                     load_avg_checked = 5
                 else:
@@ -249,7 +214,8 @@ class RtEval(rtevalReport):
                     left_to_run = stoptime - currtime
                     self.__show_remaining_time(left_to_run)
                     rpttime = currtime + report_interval
-                    print(f"load average: {self._loadmods.GetLoadAvg():.2f}")
+                    if self._loadmods:
+                        print(f"load average: {self._loadmods.GetLoadAvg():.2f}")
                 currtime = time.time()
 
             self.__logger.log(Log.DEBUG, "out of measurement loop")
@@ -257,44 +223,38 @@ class RtEval(rtevalReport):
             signal.signal(signal.SIGTERM, signal.SIG_DFL)
 
         except RuntimeError as err:
-            if not stopsig_received:
-                raise RuntimeError(f"appeared during measurement: {err}")
+            if not stopsig.is_set():
+                raise RuntimeError(f"appeared during measurement: {err}") from err
 
         finally:
             # stop measurement threads
-            measure_profile.Stop()
+            self._measuremods.Stop()
 
             # stop the loads
-            if with_loads:
+            if self._loadmods:
                 self._loadmods.Stop()
 
         print(f"stopping run at {time.asctime()}")
 
         # wait for measurement modules to finish calculating stats
-        measure_profile.WaitForCompletion()
+        self._measuremods.WaitForCompletion()
 
         return measure_start
 
 
     def Measure(self):
         """ Run the full measurement suite with reports """
-        global earlystop
+        global EARLYSTOP
         rtevalres = 0
-        measure_start = None
-        for meas_prf in self._measuremods:
-            mstart = self.__RunMeasurementProfile(meas_prf)
-            if measure_start is None:
-                measure_start = mstart
+        measure_start = self.__RunMeasurement()
+        if threaderr:
+            return 1
 
         self._report(measure_start, self.__rtevcfg.xslt_report)
         if self.__rtevcfg.sysreport:
             self._sysinfo.run_sysreport(self.__reportdir)
 
-        # if --xmlrpc-submit | -X was given, send our report to the given host
-        if self.__xmlrpc:
-            rtevalres = self.__xmlrpc.SendReport(self.GetXMLreport())
-
-        if earlystop:
+        if EARLYSTOP:
             rtevalres = 1
         self._sysinfo.copy_dmesg(self.__reportdir)
         self._tar_results()
