@@ -92,7 +92,7 @@ class RunData:
         mid = int(self.__numsamples / 2) + 1
 
         # mean, mode, and median
-        occurances = 0
+        occurrences = 0
         lastkey = -1
         for i in keys:
             if mid > total and mid <= total + self.__samples[i]:
@@ -104,8 +104,8 @@ class RunData:
             lastkey = i
             total += self.__samples[i]
             total_us += (i * self.__samples[i])
-            if self.__samples[i] > occurances:
-                occurances = self.__samples[i]
+            if self.__samples[i] > occurrences:
+                occurrences = self.__samples[i]
                 self.__mode = i
         self.__mean = float(total_us) / float(self.__numsamples)
 
@@ -270,7 +270,7 @@ class Cyclictest(rtevalModulePrototype):
 
     def _WorkloadTask(self):
         if self.__started:
-            # Don't restart cyclictest if it is already runing
+            # Don't restart cyclictest if it is already running
             return
 
         self._log(Log.DEBUG, f'starting with cmd: {" ".join(self.__cmd)}')
