@@ -79,7 +79,7 @@ class sysstat(rtevalModulePrototype):
         fp = open(self.__datafile, "rb")
         compr = bz2.BZ2Compressor(9)
         cmpr = compr.compress(fp.read())
-        data = base64.b64encode(cmpr + compr.flush())
+        data = base64.b64encode(cmpr + compr.flush()).decode('utf-8')
         data_n = rep_n.newTextChild(None, 'data', "\n"+"\n".join(textwrap.wrap(data, 75))+"\n")
         data_n.newProp('contents', 'sysstat/sar binary data')
         data_n.newProp('encoding', 'base64')
@@ -93,13 +93,6 @@ class sysstat(rtevalModulePrototype):
 
 
 
-def ModuleInfo():
-    # sysstat features - run in parallel with outher measurement modules with loads
-    return {"parallel": True,
-            "loads": True}
-
-
-
 def ModuleParameters():
     return {}  # No arguments available
 
@@ -131,7 +124,7 @@ if __name__ == '__main__':
     c._WorkloadSetup()
     c._WorkloadPrepare()
     c._WorkloadTask()
-    print("Running for approx %i seconds" % runtime)
+    print(f"Running for approx {runtime} seconds")
     while runtime > 0:
         c.WorkloadAlive()
         time.sleep(1)
